==> babylon-maven-plugin-2.0.8-sources.jar: one/edee/babylon/spring/ExporterConfiguration.java <==
package one.edee.babylon.spring;

import one.edee.babylon.db.SnapshotManager;
import one.edee.babylon.export.*;
import one.edee.babylon.sheets.gsheets.LightGSheetService;
import one.edee.babylon.sheets.gsheets.LightGSheetServiceExporterContractAdaptor;
import one.edee.babylon.snapshot.SnapshotAdapter;
import one.edee.babylon.snapshot.TranslationSnapshotReadContract;
import one.edee.babylon.snapshot.TranslationSnapshotWriteContract;
import one.edee.babylon.util.AntPathResourceLoader;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.io.IOException;

@Configuration
public class ExporterConfiguration {

    @Bean
    public Exporter exporter(TranslationCollector translationCollector,
                             TranslationSnapshotWriteContract snapshot,
                             Exporter.SheetContract sheetContract,
                             AntPathResourceLoader resourceLoader) {
        return new Exporter(translationCollector, snapshot, sheetContract, resourceLoader);
    }

    @Bean
    public TranslationCollector translationCollector(MessageLoader messageLoader,
                                              MessageFileProcessor messageFileProcessor,
                                              TranslationSnapshotReadContract snapshotReadContract,
                                              TranslationSnapshotWriteContract snapshotWriteContract) {
        return new TranslationCollector(messageLoader, messageFileProcessor, snapshotReadContract, snapshotWriteContract);
    }

    @Bean
    public MessageLoader messageLoader() {
        return new ApronMessageLoader();
    }

    @Bean
    public MessageFileProcessor messageFileProcessor(TranslationSnapshotReadContract snapshotReadContract) {
        return new MessageFileProcessor(snapshotReadContract);
    }

    @Bean
    public SnapshotAdapter snapshotAdapter(SnapshotManager snapshotManager) throws IOException {
        return new SnapshotAdapter(snapshotManager.getOrCreateDataFile());
    }

    @Bean
    public Exporter.SheetContract sheetContract(LightGSheetService lightGSheetService) {
        return new LightGSheetServiceExporterContractAdaptor(lightGSheetService);
    }

}

==> babylon-maven-plugin-2024.1.0-sources.jar: one/edee/babylon/spring/ExporterConfiguration.java <==
package one.edee.babylon.spring;

import one.edee.babylon.db.SnapshotManager;
import one.edee.babylon.export.*;
import one.edee.babylon.sheets.gsheets.LightGSheetService;
import one.edee.babylon.sheets.gsheets.LightGSheetServiceExporterContractAdaptor;
import one.edee.babylon.snapshot.SnapshotAdapter;
import one.edee.babylon.snapshot.TranslationSnapshotReadContract;
import one.edee.babylon.snapshot.TranslationSnapshotWriteContract;
import one.edee.babylon.util.AntPathResourceLoader;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.io.IOException;
import java.util.List;

@Configuration
public class ExporterConfiguration {

    @Bean
    public Exporter exporter(TranslationCollector translationCollector,
                             TranslationSnapshotWriteContract snapshot,
                             Exporter.SheetContract sheetContract,
                             AntPathResourceLoader resourceLoader) {
        return new Exporter(translationCollector, snapshot, sheetContract, resourceLoader);
    }

    @Bean
    public TranslationCollector translationCollector(List<MessageLoader> messageLoaders,
                                                     MessageFileProcessor messageFileProcessor,
                                                     TranslationSnapshotReadContract snapshotReadContract,
                                                     TranslationSnapshotWriteContract snapshotWriteContract) {
        return new TranslationCollector(messageLoaders, messageFileProcessor, snapshotReadContract, snapshotWriteContract);
    }

    @Bean
    public MessageLoader apronMessageLoader() {
        return new ApronMessageLoader();
    }
    @Bean
    public MessageLoader tsMessageLoader() {
        return new TsMessageLoader();
    }

    @Bean
    public MessageFileProcessor messageFileProcessor(TranslationSnapshotReadContract snapshotReadContract) {
        return new MessageFileProcessor(snapshotReadContract);
    }

    @Bean
    public SnapshotAdapter snapshotAdapter(SnapshotManager snapshotManager) throws IOException {
        return new SnapshotAdapter(snapshotManager.getOrCreateDataFile());
    }

    @Bean
    public Exporter.SheetContract sheetContract(LightGSheetService lightGSheetService) {
        return new LightGSheetServiceExporterContractAdaptor(lightGSheetService);
    }

}
